#!/ffp/bin/sh
#
# mysqld	This shell script takes care of starting and stopping
#		the MySQL subsystem (mysqld).
# 

# PROVIDE: mysql
# REQUIRES: 

. /ffp/etc/ffp.subr

CONF=/ffp/etc/my.cnf

name="mysql"
start_cmd="mysqld_start"
stop_cmd="mysqld_stop"
status_cmd="mysqld_status"

# extract value of a MySQL option from /ffp/etc/my.cnf
# Usage: get_mysql_option FILE VARNAME DEFAULT
# result is returned in $result
# Ugly as this is, it knows nothing of option file sections ...
get_mysql_option(){
	result=`sed -n "s/^[ \t]*$2[ \t]*=[ \t]*//p" "$1" 2>/dev/null | tail -n 1`
	if [ -z "$result" ]; then
	    # not found, use default
	    result="$3"
	else
	    # found, still have to deal with quoting and end-of-line comments
	    dequoted=`echo "$result" | sed "s/^'\([^']*\)'.*$/\1/"`
	    if [ x"$dequoted" != x"$result" ]; then
		result="$dequoted"
	    else
		dequoted=`echo "$result" | sed 's/^"\([^"]*\)".*$/\1/'`
		if [ x"$dequoted" != x"$result" ]; then
		    result="$dequoted"
		else
		    result=`echo "$result" | sed 's/^\([^ \t#]*\).*$/\1/'`
		fi
	    fi
	fi
}

get_mysql_option $CONF datadir /ffp/var/mysql
datadir="$result"
get_mysql_option $CONF socket /ffp/var/mysql.sock
socketfile="$result"
get_mysql_option $CONF err-log /ffp/var/mysqld.log
errlogfile="$result"
get_mysql_option $CONF pid-file /ffp/var/mysql.pid
mypidfile="$result"
get_mysql_option $CONF user root
myuser="$result"

command="/ffp/bin/mysqld_safe"
mysqld_safe_flags=">/dev/null 2>&1"

mysqld_start(){
    if [ ! -d "$datadir/mysql" ] ; then
	echo $"Initializing MySQL database: $datadir/mysql" 
	mysql_install_db
	ret=$?
	chown -R $myuser:$myuser "$datadir"
	if [ $ret -ne 0 ] ; then
	    return $ret
	fi
    fi
    
    _cmd=$(basename $command)
    eval _flags=\$$(echo $_cmd | tr '.' '_')_flags
    _pids=$(find_pids $_cmd)
    
    if test -z "$_pids"; then
	echo "Starting $_cmd"
	eval exec $command $_flags &
    else
	warn "$_cmd: Already running"
    fi
}

mysqld_stop(){
    _cmd=$(basename $command)
    _pids=`cat /ffp/var/mysqld.pid 2>/dev/null`
    
    if test -n "$_pids"; then
	echo "Stopping $_cmd"	
	kill $_pids
    else
	warn "$_cmd: Not running"
    fi
}

mysqld_status(){
    _cmd=$(basename $command)
    _pids=`cat /ffp/var/mysqld.pid 2>/dev/null`
        
    if test -n "$_pids"; then
	echo "$_cmd running as pid $_pids"
    else
	echo "$_cmd not running"
    fi
}
    
run_rc_command "$1"
